'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-7416068f.js');

const Button = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * The text label that appears on the button.
     */
    this.label = 'Primary Button';
    /**
     * The purpose of the button.
     */
    this.type = 'primary';
  }
  render() {
    const iconName = this.type == 'destructive' ? 'destroy' : this.icon ? this.icon : null;
    return (index.h("button", { ref: this.ref, name: this.name, class: [...getSharedStyles(), ...getStyleForType(this.type)].join(' ') }, iconName && index.h("cosmos-icon", { name: iconName, size: "m" }), index.h("span", null, this.label)));
  }
};
function getSharedStyles() {
  return ['flex', 'flex-row', 'items-center', 'space-x-3', 'text-2', 'font-sans', 'font-bold', 'whitespace-nowrap', 'h-8', 'rounded', 'focus:outline'];
}
function getStyleForType(type) {
  if (type == 'primary') {
    return getPrimaryStyle();
  }
  if (type == 'secondary') {
    return getSecondaryStyle();
  }
  if (type == 'minimal') {
    return getMinimalStyle();
  }
  if (type == 'destructive') {
    return getDestructiveStyle();
  }
}
function getPrimaryStyle() {
  return [
    'px-4',
    'shadow-1',
    'text-shadow',
    'relative',
    'text-action-primary-foreground',
    'bg-action-primary-background',
    'hover:text-action-primary-foreground-hover',
    'hover:bg-action-primary-background-hover',
    'active:top-0.5',
    'active:text-action-primary-foreground-active',
    'active:bg-action-primary-background-active',
    'active:shadow-none',
  ];
}
function getDestructiveStyle() {
  return [
    'px-4',
    'relative',
    'text-shadow',
    'bg-action-destructive-background',
    'hover:bg-action-destructive-background-hover',
    'active:bg-action-destructive-background-active',
    'text-action-destructive-foreground',
    'hover:text-action-destructive-foreground-hover',
    'active:text-action-destructive-foreground-active',
  ];
}
function getSecondaryStyle() {
  return [
    'px-4',
    'text-action-secondary-foreground',
    'hover:text-action-secondary-foreground-hover',
    'active:text-action-secondary-foreground-active',
    'bg-action-secondary-background',
    'hover:bg-action-secondary-background-hover',
    'active:bg-action-secondary-background-active',
  ];
}
function getMinimalStyle() {
  return [
    'px-3',
    'bg-action-minimal-background',
    'hover:bg-action-minimal-background-hover',
    'active:bg-action-minimal-background-active',
    'text-action-minimal-foreground',
    'hover:text-action-minimal-foreground-hover',
    'active:action-minimal-foreground-active',
  ];
}

const Checkbox = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.change = index.createEvent(this, "change", 7);
    /**
     * The visual label for the checkbox
     */
    this.label = 'Checkbox Label';
    /**
     * Whether the checkbox is selected
     */
    this.checked = false;
    /**
     * Remove all interactivity from the checkbox
     */
    this.disabled = false;
    /**
     * If the value is required or optional
     */
    this.required = false;
    this.handleStateChange = (event) => {
      const checkbox = event.target;
      // Update our internal state 
      this.internalChecked = checkbox.checked;
    };
  }
  componentWillLoad() {
    this.internalChecked = this.checked;
  }
  checkedPropChanged(newValue, _) {
    this.internalChecked = newValue;
  }
  render() {
    return (index.h("div", { class: "group flex flex-row items-center" }, index.h("input", { type: 'checkbox', id: `control-${this.name}`, name: this.name, value: this.value, disabled: this.disabled, checked: this.checked, class: getCheckboxClasses(), onChange: this.handleStateChange }), this.internalChecked == true && (index.h("div", { "aria-hidden": 'true', class: `absolute flex items-center justify-center h-5 w-5` }, index.h("cosmos-icon", { name: 'check', size: 's', color: 'text-palette-white' }))), index.h("cosmos-form-label", { required: this.required, disabled: this.disabled, text: this.label, for: this.disabled ? null : `control-${this.name}` })));
  }
  static get watchers() { return {
    "checked": ["checkedPropChanged"]
  }; }
};
function getCheckboxClasses() {
  return [
    'appearance-none',
    'rounded',
    'border',
    'border-palette-neutral-5',
    "w-5",
    "h-5",
    'mr-3',
    'disabled:border-0',
    'disabled:bg-interactive-disabled',
    'group-hover:border-interactive-hover',
    'focus:border-interactive-hover',
    //'focus:rounded-none',
    'focus:outline',
    'focus:shadow-1',
    'checked:border-interactive-selected',
    'checked:bg-interactive-selected',
    'focus:checked:border-interactive-selected',
    'group-hover:checked:border-interactive-selected',
  ].join(' ');
}

const FormLabel = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * The text content of the label
     */
    this.text = 'Form Label';
    /**
     * Is the control that is associated with this label disabled?
     */
    this.disabled = false;
    /**
     * Show a visual indicator if the input that the label represents is required
     */
    this.required = false;
  }
  render() {
    return (index.h("label", { htmlFor: this.for, class: getStyleClasses(this.for, this.disabled) }, index.h("span", null, this.text), this.required == true && index.h("span", { class: 'text-signal-warning ml-2', title: 'Required' }, "*")));
  }
};
function getStyleClasses(forElement, disabled) {
  return [
    ...(forElement !== null ? ['cursor-pointer'] : []),
    'text-2',
    'font-bold',
    disabled ? 'color-text-subtle' : 'color-text-default'
  ].join(' ');
}

const requests = new Map();
function getIconPath(name, style) {
  return index.getAssetPath(`assets/svg/${style}/${name}.svg`);
}
async function fetchIcon(name, size, iconMap) {
  // We didn't already request it.
  // Find the icon meta data from our icon map
  const iconData = iconMap.icons.find(i => i.name == name);
  if (!iconData) {
    return Promise.reject(new Error(`Icon does not exist: ${name}`));
  }
  // The icon data exists, so grab the filename
  // and see if we can fetch the actual SVG
  const iconPath = getIconPath(iconData.fileName, iconData.styles[size]);
  // See if we've already requested this icon file
  let request = requests.get(iconPath);
  if (request) {
    console.log(`Icon "${name}" already requested. Re-using`, request);
    return request;
  }
  request = fetch(iconPath).then(async (response) => {
    if (response.ok) {
      return response.text();
    }
    return Promise.reject(new Error(`Failed to fetch icon SVG file – ${response.status} ${response.statusText}`));
  });
  // Cache the request
  requests.set(iconPath, request);
  return request;
}

const icons = [
	{
		name: "more-menu",
		fileName: "ellipsis-h",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "actions-menu",
		fileName: "ellipsis-v",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "add",
		fileName: "plus",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "alert",
		fileName: "exclamation-triangle",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "chat",
		fileName: "comments",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "check",
		fileName: "check",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "close",
		fileName: "times",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "collapse",
		fileName: "angle-up",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "copy",
		fileName: "copy",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "calendar",
		fileName: "calendar",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "destroy",
		fileName: "trash",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "disable",
		fileName: "ban",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "download",
		fileName: "arrow-to-bottom",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "edit",
		fileName: "pen",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "email",
		fileName: "envelope",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "expand",
		fileName: "angle-down",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "feedback",
		fileName: "bullhorn",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "filter",
		fileName: "filter",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "help",
		fileName: "question",
		description: "",
		styles: {
			m: "solid",
			l: "solid",
			s: "solid"
		}
	},
	{
		name: "info",
		fileName: "info-circle",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "next",
		fileName: "angle-right",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "phone",
		fileName: "phone",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "previous",
		fileName: "angle-left",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "print",
		fileName: "print",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "sort-ascending",
		fileName: "caret-up",
		description: "",
		styles: {
			m: "solid",
			l: "solid",
			s: "solid"
		}
	},
	{
		name: "sort-descending",
		fileName: "caret-down",
		description: "",
		styles: {
			m: "solid",
			l: "solid",
			s: "solid"
		}
	},
	{
		name: "remove",
		fileName: "minus",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "search",
		fileName: "search",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "support",
		fileName: "user-headset",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "sync",
		fileName: "sync",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "upload",
		fileName: "arrow-to-top",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "view-grid",
		fileName: "th-large",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "view-list",
		fileName: "list",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "column-edit",
		fileName: "columns",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	},
	{
		name: "user",
		fileName: "user",
		description: "",
		styles: {
			m: "regular",
			l: "regular",
			s: "solid"
		}
	}
];
const iconMap = {
	icons: icons
};

const iconMap$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  icons: icons,
  'default': iconMap
});

const cosmosIconCss = "svg{height:100%;width:100%}";

const Icon = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Which size preset the icon uses
     */
    this.size = 'm';
  }
  connectedCallback() {
    this.loadIcon();
  }
  async loadIcon() {
    try {
      // TODO(harry): Do we need to modify any attributes here before using
      // the SVG? i.e Add `focusable="false"` to prevent IE from allowing
      // it to gain focus
      this.svg = await fetchIcon(this.name, this.size, iconMap$1);
    }
    catch (e) {
      console.error(e);
    }
  }
  render() {
    const sizeClasses = getClassesForSize(this.size);
    return (index.h(index.Host, { role: "img", class: `inline-flex items-center justify-center  ${sizeClasses[0]} ${sizeClasses[1]}` }, index.h("span", { class: `icon-inner fill-current inline-block ${this.color ? this.color : 'text-current'} ${sizeClasses[0]} ${sizeClasses[1]}`, innerHTML: this.svg || null })));
  }
  static get assetsDirs() { return ["assets"]; }
  static get watchers() { return {
    "name": ["loadIcon"],
    "size": ["loadIcon"]
  }; }
};
// UTILITIES
function getClassesForSize(size) {
  // IMPORTANT(harry): We have to use the full tailwind
  // class names here instead of building them dynamicaly
  // so the classes aren't purged by PurgeCSS
  switch (size) {
    case 's':
      return ['w-4', 'h-4'];
    case 'm':
      return ['w-5', 'h-5'];
    case 'l':
      return ['w-6', 'h-6'];
  }
}
Icon.style = cosmosIconCss;

exports.cosmos_button = Button;
exports.cosmos_checkbox = Checkbox;
exports.cosmos_form_label = FormLabel;
exports.cosmos_icon = Icon;
